@@ -64,12 +64,12 @@ class SurfaceGenerator(Sequence):
         >>> from pymatgen.core.structure import Structure
         >>> bulk = Structure.from_file("POSCAR_bulk")
         >>> surfaces = SurfaceGenerator(bulk=bulk, miller_index=[1, 1, 1], layers=5, vacuum=60)
-        >>> surface = surfaces.slabs[0] # OgreInterface.Surface object
+        >>> surface = surfaces[0] # OgreInterface.Surface object
 
         Creating a SurfaceGenerator object using the build in from_file() method:
         >>> from OgreInterface.generate import SurfaceGenerator
         >>> surfaces = SurfaceGenerator.from_file(filename="POSCAR_bulk", miller_index=[1, 1, 1], layers=5, vacuum=60)
-        >>> surface = surfaces.slabs[0] # OgreInterface.Surface object
+        >>> surface = surfaces[0] # OgreInterface.Surface object
 
     Args:
         bulk: Bulk crystal structure used to create the surface
@@ -156,7 +156,7 @@ class SurfaceGenerator(Sequence):
         else:
             self._slabs = None
 
-    def __getitem__(self, i):
+    def __getitem__(self, i) -> Surface:
         if self._slabs:
             return self._slabs[i]
         else:
@@ -164,7 +164,7 @@ class SurfaceGenerator(Sequence):
                 "The slabs have not been generated yet, please use the generate_slabs() function to create them."
             )
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._slabs)
 
     def generate_slabs(self) -> None:
@@ -478,7 +478,8 @@ class SurfaceGenerator(Sequence):
         planar_matrix = deepcopy(planar_oriented_struc.lattice.matrix)
 
         new_a, new_b, mat = utils.reduce_vectors_zur_and_mcgill(
-            planar_matrix[0, :2], planar_matrix[1, :2]
+            planar_matrix[0],
+            planar_matrix[1],
         )
 
         planar_oriented_struc.make_supercell(mat)
@@ -652,6 +653,15 @@ class SurfaceGenerator(Sequence):
             to_unit_cell=True,
         )
 
+        slab_base = Structure(
+            lattice=self.oriented_bulk_structure.lattice,
+            species=self.oriented_bulk_structure.species,
+            coords=np.round(slab_base.frac_coords, 6),
+            to_unit_cell=True,
+            coords_are_cartesian=False,
+            site_properties=self.oriented_bulk_structure.site_properties,
+        )
+
         bottom_layer_dist = np.abs(bot_z - (top_z - 1)) * init_matrix[-1, -1]
         top_layer_dist = np.abs((bot_z + 1) - top_z) * init_matrix[-1, -1]
 
@@ -696,16 +706,24 @@ class SurfaceGenerator(Sequence):
             frac_coords=True,
             to_unit_cell=True,
         )
+        top_z = non_orthogonal_slab.frac_coords[:, -1].max()
+        top_cart = non_orthogonal_slab.lattice.matrix[-1] * top_z
+        top_cart[-1] = 0.0
+        orthogonal_slab.translate_sites(
+            indices=range(len(orthogonal_slab)),
+            vector=-top_cart,
+            frac_coords=False,
+            to_unit_cell=True,
+        )
 
-        # shift_str = f"{shift:.3f}".replace(".", "")
-        # Poscar(non_orthogonal_slab).write_file(f"POSCAR_slab_com_{shift_str}")
-
-        # if "molecules" in slab_base.site_properties:
-        #     slab_base = utils.add_molecules(slab_base)
-        #     orthogonal_slab = utils.add_molecules(orthogonal_slab)
-        #     non_orthogonal_slab = utils.add_molecules(non_orthogonal_slab)
-
-        # Poscar(non_orthogonal_slab).write_file(f"POSCAR_slab_mol_{shift_str}")
+        orthogonal_slab = Structure(
+            lattice=orthogonal_slab.lattice,
+            species=orthogonal_slab.species,
+            coords=np.round(orthogonal_slab.frac_coords, 6),
+            to_unit_cell=True,
+            coords_are_cartesian=False,
+            site_properties=orthogonal_slab.site_properties,
+        )
 
         return (
             slab_base,
@@ -829,12 +847,12 @@ class OrganicSurfaceGenerator(SurfaceGenerator):
         >>> from pymatgen.core.structure import Structure
         >>> bulk = Structure.from_file("POSCAR_bulk")
         >>> surfaces = SurfaceGenerator(bulk=bulk, miller_index=[1, 1, 1], layers=5, vacuum=60)
-        >>> surface = surfaces.slabs[0] # OgreInterface.Surface object
+        >>> surface = surfaces[0] # OgreInterface.Surface object
 
         Creating a SurfaceGenerator object using the build in from_file() method:
         >>> from OgreInterface.generate import SurfaceGenerator
         >>> surfaces = SurfaceGenerator.from_file(filename="POSCAR_bulk", miller_index=[1, 1, 1], layers=5, vacuum=60)
-        >>> surface = surfaces.slabs[0] # OgreInterface.Surface object
+        >>> surface = surfaces[0] # OgreInterface.Surface object
 
     Args:
         bulk: Bulk crystal structure used to create the surface
@@ -1002,7 +1020,7 @@ class InterfaceGenerator:
         >>> from OgreInterface.generate import SurfaceGenerator, InterfaceGenerator
         >>> subs = SurfaceGenerator.from_file(filename="POSCAR_sub", miller_index=[1,1,1], layers=5)
         >>> films = SurfaceGenerator.from_file(filename="POSCAR_film", miller_index=[1,1,1], layers=5)
-        >>> interface_generator = InterfaceGenerator(substrate=subs.slabs[0], film=films.slabs[0])
+        >>> interface_generator = InterfaceGenerator(substrate=subs[0], film=films[0])
         >>> interfaces = interface_generator.generate_interfaces() # List of OgreInterface Interface objects
 
     Args:
